@@ -9,6 +9,23 @@ raise ImportError, "I told you not to import this module"
 
 _ = None
 
+class GtkCTreeNode:
+	"""This representsa node in a GtkCTree.  It is a cross between the"""
+	"""C GtkCTreeNode and GtkCTreeRow structs."""
+
+	"""The parent of this node (or None for no parent)"""
+	parent = _
+	"""This node's next sibling (or None if this is the last)"""
+	sibling = _
+	"""A list of this node's children"""
+	children = []
+	"""The level of this node"""
+	level = _
+	"""TRUE if this node is a leaf node"""
+	is_leaf = _
+	"""TRUE if this node has been expanded"""
+	expanded = _
+
 class GtkStyle:
 	"""Currently you can't assign to any of the attributes of a GtkStyle"""
 	"""This type can't be instantiated directly"""
