@@ -69,27 +69,40 @@ class GtkDb(GtkWindow, bdb.Bdb):
 		vpane.add1(hpane)
 		hpane.show()
 
+		swin = GtkScrolledWindow()
+		swin.set_policy(POLICY_AUTOMATIC, POLICY_AUTOMATIC)
+		hpane.add1(swin)
+		swin.show()
+
 		self.stackdisp = GtkCList(1, ['Stack Frame'])
 		self.stackdisp.connect("select_row", self.update_curstack)
 		self.stackdisp.set_usize(280, 125)
-		self.stackdisp.set_policy(POLICY_AUTOMATIC, POLICY_AUTOMATIC)
 		self.stackdisp.set_selection_mode(SELECTION_BROWSE)
-		self.stackdisp.border_width(2)
-		hpane.add1(self.stackdisp)
+		self.stackdisp.set_border_width(2)
+		swin.add(self.stackdisp)
 		self.stackdisp.show()
 
+		swin = GtkScrolledWindow()
+		swin.set_policy(POLICY_AUTOMATIC, POLICY_AUTOMATIC)
+		hpane.add2(swin)
+		swin.show()
+
 		self.vardisp = GtkCList(3, ['local var', 'type', 'value'])
 		self.vardisp.connect("select_row", self.update_selectedvar)
-		self.vardisp.set_policy(POLICY_AUTOMATIC, POLICY_AUTOMATIC)
 		self.vardisp.set_selection_mode(SELECTION_BROWSE)
 		self.vardisp.set_column_width(0, 75)
 		self.vardisp.set_column_width(1, 30)
-		self.vardisp.border_width(2)
-		hpane.add2(self.vardisp)
+		self.vardisp.set_border_width(2)
+		swin.add(self.vardisp)
 		self.vardisp.show()
 		self.vardisp.selected = 0
 		self.vardisp.varnames = []
 
+		swin = GtkScrolledWindow()
+		swin.set_policy(POLICY_AUTOMATIC, POLICY_AUTOMATIC)
+		vpane.add2(swin)
+		swin.show()
+
 		self.filedisp = GtkCList(3, ['break', 'lineno', 'line'])
 		self.minibreak = GtkPixmap(self, "minibreak.xpm")
 		# This is giving a warning -- probably a bug in GTK
@@ -99,11 +112,10 @@ class GtkDb(GtkWindow, bdb.Bdb):
 		self.filedisp.set_column_width(1, 35)
 		self.filedisp.connect("select_row", self.update_selection)
 		self.filedisp.set_column_justification(1, JUSTIFY_RIGHT)
-		self.filedisp.set_policy(POLICY_AUTOMATIC, POLICY_AUTOMATIC)
 		self.filedisp.set_selection_mode(SELECTION_BROWSE)
-		self.filedisp.border_width(2)
+		self.filedisp.set_border_width(2)
 		self.filedisp.set_usize(600, 200)
-		vpane.add2(self.filedisp)
+		swin.add(self.filedisp)
 		self.filedisp.show()
 
 		separator = GtkHSeparator()
