@@ -1,9 +1,9 @@
 #!/usr/bin/env python
 
 # translation of "Hello World III" from GTK manual, using new() function
-# from Gtkinter.  Also implements a tooltip for the button.
+# from gtk.py.  Also implements a tooltip for the button.
 
-from Gtkinter import *
+from gtk import *
 
 def hello(*args):
 	print "Hello World"
