@@ -247,10 +247,10 @@ class GtkWidget(GtkObject):
 	def drag_set_default_icon(self, colormap, pixmap, mask, hot_x, hot_y):
 		_gtk.gtk_drag_set_default_icon(colormap, pixmap, mask,
 					       hot_x, hot_y)
+	def drag_get_source_widget(self, context):
+		return _obj2inst(_gtk.gtk_drag_get_source_widget(context))
 	def draw(self, rect):
 		_gtk.gtk_widget_draw(self._o, rect)
-	def draw_children(self, obj=None):
-		_gtk.gtk_widget_draw_children(self._o)
 	def draw_default(self, obj=None):
 		_gtk.gtk_widget_draw_default(self._o)
 	def draw_focus(self, obj=None):
@@ -259,10 +259,12 @@ class GtkWidget(GtkObject):
 		_gtk.gtk_widget_ensure_style(self._o)
 	def event(self, event):
 		_gtk.gtk_widget_event
-	def freeze_accelerators(self):
-		_gtk.gtk_widget_freeze_accelerators(self._o)
+	def lock_accelerators(self):
+		_gtk.gtk_widget_lock_accelerators(self._o)
 	def get_ancestor(self, type):
 		return _obj2inst(_gtk.gtk_widget_get_ancestor(self._o, type))
+	def get_composite_name(self):
+		return _gtk.gtk_widget_get_composite_name(self._o)
 	def get_events(self):
 		return _gtk.gtk_widget_get_events(self._o)
 	def get_extension_events(self):
@@ -293,8 +295,6 @@ class GtkWidget(GtkObject):
 		return _gtk.gtk_widget_intersect(self._o, rect)
 	def is_ancestor(self, a):
 		return _gtk.gtk_widget_is_ancestor(self._o, a._o)
-	def is_child(self, c):
-		return _gtk.gtk_widget_is_child(self._o, c._o)
 	def map(self, obj=None):
 		_gtk.gtk_widget_map(self._o)
 	def popup(self, x, y):
@@ -317,8 +317,6 @@ class GtkWidget(GtkObject):
 		_gtk.gtk_widget_reset_rc_styles(self._o)
 	def restore_default_style(self):
 		_gtk.gtk_widget_restore_default_style(self._o)
-	def scroll_adjustments(self, hadj, vadj):
-		_gtk.gtk_widget_scroll_adjustments(self._o, hadj._o, vadj._o)
 	def selection_owner_set(self, selection, time):
 		return _gtk.gtk_selection_owner_set(self._o, selection, time)
 	def selection_add_target(self, selection, target, info):
@@ -332,6 +330,8 @@ class GtkWidget(GtkObject):
 		_gtk.gtk_widget_set_events(self._o, events)
 	def add_events(self, events):
 		_gtk.gtk_widget_add_events(self._o, events)
+	def set_composite_name(self, name):
+		_gtk.gtk_widget_set_composite_name(self._o, name)
 	def set_extension_events(self, exevents):
 		_gtk.gtk_widget_set_extension_events(self._o, exevents)
 	def set_name(self, name):
@@ -340,6 +340,8 @@ class GtkWidget(GtkObject):
 		_gtk.gtk_widget_set_parent(self._o, parent._o)
 	def set_parent_window(self, parent):
 		_gtk.gtk_widget_set_parent_window(self._o, parent)
+	def set_scroll_adjustments(self, hadj, vadj):
+		_gtk.gtk_widget_set_scroll_adjustments(self._o,hadj._o,vadj._o)
 	def set_sensitive(self, s):
 		_gtk.gtk_widget_set_sensitive(self._o, s)
 	def set_state(self, s):
@@ -366,8 +368,8 @@ class GtkWidget(GtkObject):
 		_gtk.gtk_widget_size_allocate(self._o, a)
 	def size_request(self):
 		return _gtk.gtk_widget_size_request(self._o)
-	def thaw_accelerators(self):
-		_gtk.gtk_widget_thaw_accelerators(self._o)
+	def unlock_accelerators(self):
+		_gtk.gtk_widget_unlock_accelerators(self._o)
 	def unmap(self, obj=None):
 		_gtk.gtk_widget_unmap(self._o)
 	def unparent(self):
@@ -409,9 +411,15 @@ class GtkContainer(GtkWidget):
 		else:
 			_gtk.gtk_container_add(self._o, child._o, args)
 	def border_width(self, bw):
-		_gtk.gtk_container_border_width(self._o, bw)
+		print "border_width deprecated -- use set_border_width"
+		self.set_border_width(bw)
+	def set_border_width(self, bw):
+		_gtk.gtk_container_set_border_width(self._o, bw)
 	def check_resize(self):
 		_gtk.gtk_container_check_resize(self._o)
+	def child_composite_name(self, child):
+		return _gtk.gtk_container_child_composite_name(self._o,
+							       child._o)
 	def child_set(self, child, **args):
 		_gtk.gtk_container_child_set(self._o, child._o, args)
 	def child_get(self, child, arg):
@@ -735,7 +743,10 @@ class GtkWindow(GtkBin):
 	def remove_accel_group(self, group):
 		_gtk.gtk_window_remove_accel_group(self._o, group._ag)
 	def position(self, pos):
-		_gtk.gtk_window_position(self._o, pos)
+		print "position deprecated -- use set_position"
+		self.set_position(pos)
+	def set_position(self, pos):
+		_gtk.gtk_window_set_position(self._o, pos)
 	def set_wmclass(self, wmc_name, wmc_class):
 		_gtk.gtk_window_set_wmclass(self._o, wmc_name, wmc_class)
 	def set_icon(self, pixmap, mask=None):
@@ -744,6 +755,10 @@ class GtkWindow(GtkBin):
 		_gtk.gtk_window_set_icon(self._o, pixmap, mask)
 	def set_icon_name(self, name):
 		_gtk.gtk_window_set_icon_name(self._o, name)
+	def set_transient_for(self, parent):
+		_gtk.gtk_window_set_transient_for(self._o, parent._o)
+	def set_default_size(self, width, height):
+		_gtk.gtk_window_set_default_size(self._o, width, height)
 	def set_modal(self, modal):
 		_gtk.gtk_window_set_modal(self._o, modal)
 
@@ -858,6 +873,12 @@ class GtkFontSelectionDialog(GtkWindow):
 	def set_preview_text(self, text):
 		_gtk.gtk_font_selection_dialog_set_preview_text(self._o, text)
 
+class GtkPlug(GtkWindow):
+	get_type = _gtk.gtk_plug_get_type
+	def __init__(self, socket_id=-1, _obj=None):
+		if _obj: self._o = _obj; return
+		self._o = _gtk.gtk_plug_new(socket_id)
+
 class GtkBox(GtkContainer):
 	get_type = _gtk.gtk_box_get_type
 	def __init__(self, _obj=None):
@@ -1055,6 +1076,8 @@ class GtkCList(GtkContainer):
 		_gtk.gtk_clist_column_titles_passive(self._o)
 	def column_titles_show(self, obj=None):
 		_gtk.gtk_clist_column_titles_show(self._o)
+	def columns_autosize(self):
+		return _gtk.gtk_clist_columns_autosize(self._o)
 	def find_row_from_data(self, data):
 		return _gtk.gtk_clist_find_row_from_data(self._o, data)
 	def freeze(self, obj=None):
@@ -1091,6 +1114,8 @@ class GtkCList(GtkContainer):
 		_gtk.gtk_clist_remove(self._o, row)
 	def row_is_visible(self, row):
 		return _gtk.gtk_clist_row_is_visible(self._o, row)
+	def row_move(self, soure_row, dest_row):
+		_gtk.gtk_clist_row_move(self._o, source_row, dest_row)
 	def select_all(self):
 		_gtk.gtk_clist_select_all(self._o)
 	def select_row(self, row, col):
@@ -1173,6 +1198,143 @@ class GtkCList(GtkContainer):
 	def unselect_row(self, row, col):
 		_gtk.gtk_clist_unselect_row(self._o, row, col)
 
+class GtkCTree(GtkCList):
+	get_type = _gtk.gtk_ctree_get_type
+	def __init__(self, cols=1, tree_col=0, titles=None, _obj=None):
+		if _obj: self._o = _obj; return
+		if titles == None:
+			self._o = _gtk.gtk_ctree_new(cols, tree_col)
+		else:
+			self._o = _gtk.gtk_ctree_new_with_titles(cols,
+								 tree_col,
+								 titles)
+	def base_nodes(self):
+		# this returns a list of the base nodes.  Useful for recursion
+		return _gtk.gtk_ctree_base_nodes(self._o)
+	def insert_node(self, parent, sibling, text, spacing=5,
+			pixmap_closed=None, mask_closed=None,
+			pixmap_opened=None, mask_opened=None, is_leaf=TRUE,
+			expanded=FALSE):
+		# parent and sibling can also be None
+		return _gtk.gtk_ctree_insert_node(self._o, parent, sibling,
+						  text, spacing,
+						  pixmap_closed, mask_closed,
+						  pixmap_opened, mask_opened,
+						  is_leaf, expanded)
+	def remove_node(self, node):
+		_gtk.gtk_ctree_remove_node(self._o, node)
+	def is_viewable(self, node):
+		return _gtk.gtk_ctree_is_viewable(self._o, node)
+	def last(self, node):
+		return _gtk.gtk_ctree_last(self._o, node)
+	def node_nth(self, row):
+		return _gtk.gtk_ctree_node_nth(self._o, row)
+	def find(self, node, child):
+		return _gtk.gtk_ctree_find(self._o, node, child)
+	def is_ancestor(self, node, child):
+		return _gtk.gtk_ctree_is_ancestor(self._o, node, child)
+	def find_by_row_data(self, node, data):
+		return _gtk.gtk_ctree_find_by_row_data(self._o, node, data)
+	def find_all_by_row_data(self, node, data):
+		return _gtk.gtk_ctree_find_all_by_row_data(self._o, node, data)
+	def is_hot_spot(self, x, y):
+		return _gtk.gtk_ctree_is_hot_spot(self._o, x, y)
+	def move(self, node, new_parent, new_sibling):
+		_gtk.gtk_ctree_move(self._o, node, new_parent, new_sibling)
+	def expand(self, node):
+		_gtk.gtk_ctree_expand(self._o, node)
+	def expand_recursive(self, node):
+		_gtk.gtk_ctree_expand_recursive(self._o, node)
+	def expand_to_depth(self, node, depth):
+		_gtk.gtk_ctree_expand_to_depth(self._o, node, depth)
+	def collapse(self, node):
+		_gtk.gtk_ctree_collapse(self._o, node)
+	def collapse_recursive(self, node):
+		_gtk.gtk_ctree_collapse_recursive(self._o, node)
+	def collapse_to_depth(self, node, depth):
+		_gtk.gtk_ctree_collapse_to_depth(self._o, node, depth)
+	def toggle_expansion(self, node):
+		_gtk.gtk_ctree_toggle_expansion(self._o, node)
+	def toggle_expansion_recursive(self, node):
+		_gtk.gtk_ctree_toggle_expansion_recursive(self._o, node)
+	def select(self, node):
+		_gtk.gtk_ctree_select(self._o, node)
+	def select_recursive(self, node):
+		_gtk.gtk_ctree_select_recursive(self._o, node)
+	def unselect(self, node):
+		_gtk.gtk_ctree_unselect(self._o, node)
+	def unselect_recursive(self, node):
+		_gtk.gtk_ctree_unselect_recursive(self._o, node)
+	def real_select_recursive(self, node, state):
+		_gtk.gtk_ctree_real_select_recursive(self._o, node, state)
+	def node_set_text(self, node, col, text):
+		_gtk.gtk_ctree_node_set_text(self._o, node, col, text)
+	def node_set_pixmap(self, node, col, pixmap, mask):
+		_gtk.gtk_ctree_node_set_pixmap(self._o, node, col, pixmap,mask)
+	def node_set_pixtext(self, node, col, text, spacing, pixmap, mask):
+		_gtk.gtk_ctree_node_set_pixtext(self._o, node, col, text,
+						spacing, pixmap, mask)
+	def set_node_info(self, node, text, spacing, pixmap_closed,
+			  mask_closed, pixmap_opened, mask_opened, is_leaf,
+			  expanded):
+		_gtk.gtk_ctree_set_node_info(self._o, node, text, spacing,
+					     pixmap_closed, mask_closed,
+					     pixmap_opened, mask_opened,
+					     is_leaf, expanded)
+	def node_set_shift(self, node, col, vert, horiz):
+		_gtk.gtk_ctree_node_set_shift(self._o, node, col, vert, horiz)
+	def node_set_selectable(self, node, selectable):
+		_gtk.gtk_ctree_node_set_selectable(self._o, node, selectable)
+	def node_get_cell_type(self, node, col):
+		return _gtk.gtk_ctree_node_get_cell_type(self._o, node, col)
+	def node_get_text(self, node, col):
+		return _gtk.gtk_ctree_node_get_text(self._o, node, col)
+	def node_get_pixmap(self, node, col):
+		return _gtk.gtk_ctree_node_get_pixmap(self._o, node, col)
+	def node_get_pixtext(self, node, col):
+		return _gtk.gtk_ctree_node_get_pixtext(self._o, node, col)
+	def get_node_info(self, node):
+		return _gtk.gtk_ctree_get_node_info(self._o, node)
+	def node_set_row_style(self, node, style):
+		_gtk.gtk_ctree_node_set_row_style(self._o, node, style)
+	def node_get_row_style(self, node):
+		return _gtk.gtk_ctree_node_get_row_style(self._o, node)
+	def node_set_cell_style(self, node, col, style):
+		_gtk.gtk_ctree_node_set_row_style(self._o, node, col, style)
+	def node_get_cell_style(self, node, col):
+		return _gtk.gtk_ctree_node_get_row_style(self._o, node, col)
+	def node_set_foreground(self, node, color):
+		_gtk.gtk_ctree_node_set_foreground(self._o, node, color)
+	def node_set_background(self, node, color):
+		_gtk.gtk_ctree_node_set_background(self._o, node, color)
+	def node_set_row_data(self, node, data):
+		_gtk.gtk_ctree_node_set_row_data(self._o, node, data)
+	def node_get_row_data(self, node):
+		return _gtk.gtk_ctree_node_get_row_data(self._o, node)
+	def node_moveto(self, node, col, row_align, col_align):
+		_gtk.gtk_ctree_node_moveto(self._o, node, col, row_align,
+					   col_align)
+	def node_is_visible(self, node):
+		return _gtk.gtk_ctree_node_is_visible(self._o, node)
+	def set_indent(self, indent):
+		_gtk.gtk_ctree_set_indent(self._o, indent)
+	def set_spacing(self, spacing):
+		_gtk.gtk_ctree_set_spacing(self._o, spacing)
+	def set_show_stub(self, show_stub):
+		_gtk.gtk_ctree_set_show_stub(self._o, show_stub)
+	def set_reorderable(self, reorderable):
+		_gtk.gtk_ctree_set_reorderable(self._o, reorderable)
+	def set_use_drag_icons(self, use_icons):
+		_gtk.gtk_ctree_set_use_drag_icons(self._o, use_icons)
+	def set_line_style(self, style):
+		_gtk.gtk_ctree_set_line_style(self._o, style)
+	def set_expander_style(self, style):
+		_gtk.gtk_ctree_set_expander_style(self._o, style)
+	def sort_node(self, node):
+		_gtk.gtk_ctree_sort_node(self._o, node)
+	def sort_recursive(self, node):
+		_gtk.gtk_ctree_sort_recursive(self._o, node)
+
 class GtkFixed(GtkContainer):
 	get_type = _gtk.gtk_fixed_get_type
 	def __init__(self, _obj=None):
@@ -1183,6 +1345,35 @@ class GtkFixed(GtkContainer):
 	def move(self, child, x, y):
 		_gtk.gtk_fixed_move(self._o, child._o, x, y)
 
+class GtkLayout(GtkContainer):
+	get_type = _gtk.gtk_layout_get_type
+	def __init__(self, hadj=None, vadj=None, _obj=None):
+		if _obj: self._o = _obj; return
+		if hadj and vadj:
+			self._o = _gtk.gtk_layout_new(hadj._o, vadj._o)
+		else:
+			self._o = _gtk.gtk_layout_new()
+	def put(self, child, x, y):
+		_gtk.gtk_layout_put(self._o, child._o, x, y)
+	def move(self, child, x, y):
+		_gtk.gtk_layout_move(self._o, child._o, x, y)
+	def set_size(self, width, height):
+		_gtk.gtk_layout_set_size(self._o, width, height)
+	def freeze(self):
+		_gtk.gtk_layout_freeze(self._o)
+	def thaw(self):
+		_gtk.gtk_layout_thaw(self._o)
+	def get_hadjustment(self):
+		return GtkAdjustment(
+			_obj=_gtk.gtk_layout_get_hadjustment(self._o))
+	def get_vadjustment(self):
+		return GtkAdjustment(
+			_obj=_gtk.gtk_layout_get_vadjustment(self._o))
+	def set_hadjustment(self, adj):
+		_gtk.gtk_layout_set_hadjustment(self._o, adj._o)
+	def set_vadjustment(self, adj):
+		_gtk.gtk_layout_set_vadjustment(self._o, adj._o)
+
 class GtkList(GtkContainer):
 	get_type = _gtk.gtk_list_get_type
 	def __init__(self, _obj=None):
@@ -1326,7 +1517,13 @@ class GtkNotebook(GtkContainer):
 	def remove_page(self, pos):
 		_gtk.gtk_notebook_remove_page(self._o, pos)
 	def current_page(self):
-		return _gtk.gtk_notebook_current_page(self._o)
+		print "current_page deprecated -- use get_current_page"
+		return self.current_page()
+	def get_current_page(self):
+		return _gtk.gtk_notebook_get_current_page(self._o)
+	def get_nth_page(self, page_num):
+		return _obj2inst(_gtk.gtk_notebook_get_nth_page(self._o,
+								page_num))
 	def page_num(self, child):
 		return _gtk.gtk_notebook_page_num(self._o, child._o)
 	def set_page(self, pos):
@@ -1360,16 +1557,22 @@ class GtkNotebook(GtkContainer):
 	def popup_disable(self, obj=None):
 		_gtk.gtk_notebook_popup_disable(self._o)
 	def query_tab_label(self, child):
-		return _obj2inst(_gtk.gtk_notebook_query_tab_label(self._o,
-								   child._o))
+		print "query_tab_label deprecated -- use get_tab_label"
+		return self.get_tab_label(child)
+	def get_tab_label(self, child):
+		return _obj2inst(_gtk.gtk_notebook_get_tab_label(self._o,
+								 child._o))
 	def set_tab_label(self, child, tab_label):
 		_gtk.gtk_notebook_set_tab_label(self._o, child._o,
 						tab_label._o)
 	def set_tab_label_text(self, child, tab_text):
 		_gtk.gtk_notebook_set_tab_label(self._o, child._o, tab_text)
 	def query_menu_label(self, child):
-		return _obj2inst(_gtk.gtk_notebook_query_menu_label(self._o,
-								    child._o))
+		print "query_menu_label deprecated -- use get_menu_label"
+		return self.get_menu_label(child)
+	def get_menu_label(self, child):
+		return _obj2inst(_gtk.gtk_notebook_get_menu_label(self._o,
+								  child._o))
 	def set_menu_label(self, child, menu_label):
 		_gtk.gtk_notebook_set_menu_label(self._o, child._o,
 						menu_label._o)
@@ -1415,9 +1618,16 @@ class GtkPacker(GtkContainer):
 				    i_pad_y)
 	def configure(self, child, side, anchor, options, border_width, pad_x,
 		      pad_y, i_pad_x, i_pad_y):
-		_gtk.gtk_packer_configure(self._o, child._o, side, anchor,
-					  options, border_width, pad_x, pad_y,
-					  i_pad_x, i_pad_y)
+		print "configure deprecated -- use set_child_packing"
+		self.set_child_packing(child, side, anchor, options,
+				       border_width, pad_x, pad_y, i_pad_x,
+				       i_pad_y)
+	def set_child_packing(self, child, side, anchor, options,
+			      border_width, pad_x, pad_y, i_pad_x, i_pad_y):
+		_gtk.gtk_packer_set_child_packing(self._o, child._o, side,
+						  anchor, options,
+						  border_width, pad_x, pad_y,
+						  i_pad_x, i_pad_y)
 	def reorder_child(self, child, pos):
 		_gtk.gtk_packer_reorder_child(self._o, child._o, pos)
 	def set_spacing(self, spacing):
@@ -1436,9 +1646,15 @@ class GtkPaned(GtkContainer):
 	def add2(self, child):
 		_gtk.gtk_paned_add2(self._o, child._o)
 	def handle_size(self, size):
-		_gtk.gtk_paned_handle_size(self._o, size)
+		print "handle_size deprecated -- use set_handle_size"
+		self.set_handle_size(size)
+	def set_handle_size(self, size):
+		_gtk.gtk_paned_set_handle_size(self._o, size)
 	def gutter_size(self, size):
-		_gtk.gtk_paned_gutter_size(self._o, size)
+		print "gutter_size deprecated -- use set_gutter_size"
+		self.set_gutter_size(size)
+	def set_gutter_size(self, size):
+		_gtk.gtk_paned_set_gutter_size(self._o, size)
 
 class GtkHPaned(GtkPaned):
 	get_type = _gtk.gtk_hpaned_get_type
@@ -1477,6 +1693,14 @@ class GtkScrolledWindow(GtkContainer):
 	def add_with_viewport(self, child):
 		_gtk.gtk_scrolled_window_add_with_viewport(self._o, child._o)
 
+class GtkSocket(GtkContainer):
+	get_type = _gtk.gtk_socket_get_type
+	def __init__(self, _obj=None):
+		if _obj: self._o = _obj; return
+		self._o = _gtk.gtk_socket_new()
+	def steal(self, wid):
+		_gtk.gtk_socket_steal(self._o, wid)
+
 class GtkTable(GtkContainer):
 	get_type = _gtk.gtk_table_get_type
 	def __init__(self, rows=1, cols=1, homogeneous=0, _obj=None):
@@ -1543,22 +1767,22 @@ class GtkToolbar(GtkContainer):
 		if _obj: self._o = _obj; return
 		self._o = _gtk.gtk_toolbar_new(orientation, style)
         def append_item(self, text, tooltip, tp, icon, callback):
-		_gtk.gtk_toolbar_append_item(self._o, text, tooltip, tp,
-					     icon._o, callback)
+		return _obj2inst(_gtk.gtk_toolbar_append_item(
+			self._o, text, tooltip, tp, icon._o, callback))
 	def append_space(self):
 		_gtk.gtk_toolbar_append_space(self._o)
 	def append_widget(self, w, tooltip, tp):
 		_gtk.gtk_toolbar_append_widget(self._o, w._o, tooltip, tp)
 	def insert_item(self, text, tooltip, tp, icon, callback, pos):
-		_gtk.gtk_toolbar_insert_item(self._o, text, tooltip, tp,
-					     icon._o, callback, pos)
+		return _obj2inst(_gtk.gtk_toolbar_insert_item(
+			self._o, text, tooltip, tp, icon._o, callback, pos))
 	def insert_space(self, pos):
 		_gtk.gtk_toolbar_insert_space(self._o, pos)
 	def insert_widget(self, w, tooltip, tp, pos):
 		_gtk.gtk_toolbar_insert_widget(self._o, w._o, tooltip, tp, pos)
 	def prepend_item(self, text, tooltip, tp, icon, callback):
-		_gtk.gtk_toolbar_prepend_item(self._o, text, tooltip, tp,
-					      icon._o, callback)
+		return _obj2inst(_gtk.gtk_toolbar_prepend_item(
+			self._o, text, tooltip, tp, icon._o, callback))
 	def prepend_space(self):
 		_gtk.gtk_toolbar_prepend_space(self._o)
 	def prepend_widget(self, w, tooltip, tp):
@@ -1569,6 +1793,8 @@ class GtkToolbar(GtkContainer):
 		_gtk.gtk_toolbar_set_style(self._o, style)
 	def set_space_size(self, size):
 		_gtk.gtk_toolbar_set_space_size(self._o, size)
+	def set_space_style(self, style):
+		_gtk.gtk_toolbar_set_space_style(self._o, style)
 	def set_tooltips(self, enable):
 		_gtk.gtk_toolbar_set_tooltips(self._o, enable)
 	def set_button_relief(self, relief):
@@ -1839,7 +2065,10 @@ class GtkAccelLabel(GtkLabel):
 		if _obj: self._o = _obj; return
 		self._o = _gtk.gtk_accel_label_new(string)
 	def accelerator_width(self):
-		return _gtk.gtk_accel_label_width(self._o)
+		print "accelerator_width deprecated -- use get_accel_width"
+		return self.get_accel_width()
+	def get_accel_width(self):
+		return _gtk.gtk_accel_label_get_accel_width(self._o)
 	def set_accel_widget(self, widget):
 		_gtk.gtk_accel_label_set_accel_widget(self._o, widget._o)
 	def refetch(self):
@@ -1898,6 +2127,9 @@ class GtkProgress(GtkWidget):
 	def set_adjustment(self, adj):
 		_gtk.gtk_progress_set_adjustment(self._o, adj._o)
 	def reconfigure(self, value, min, max):
+		print "reconfigure deprecated -- use configure"
+		self.configure(value, min, max)
+	def configure(self, value, min, max):
 		_gtk.gtk_progress_reconfigure(self._o, value, min, max)
 	def set_percentage(self, pcnt):
 		_gtk.gtk_progress_set_percentage(self._o, pcnt)
@@ -1971,7 +2203,10 @@ class GtkScale(GtkRange):
 	def set_value_pos(self, pos):
 		_gtk.gtk_scale_set_value_pos(self._o, pos)
 	def value_width(self):
-		return _gtk.gtk_scale_value_width(self._o)
+		print "value_width deprecated -- use get_value_width"
+		return self.get_value_width()
+	def get_value_width(self):
+		return _gtk.gtk_scale_get_value_width(self._o)
 	def draw_value(self, obj=None):
 		_gtk.gtk_scale_draw_value(self._o)
 
